/*
 * Copyright (c) "Neo4j"
 * Neo4j Sweden AB [https://neo4j.com]
 *
 * This file is part of Neo4j.
 *
 * Neo4j is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <https://www.gnu.org/licenses/>.
 */
package org.neo4j.kernel.api.exceptions;

import org.neo4j.exceptions.KernelException;
import org.neo4j.gqlstatus.ErrorGqlStatusObject;
import org.neo4j.gqlstatus.ErrorGqlStatusObjectImplementation;
import org.neo4j.gqlstatus.GqlStatusInfoCodes;

/**
 * This exception is thrown when committing an updating transaction in a database which is configured as read-only, through configuration or ALTER DATABASE.
 */
public class WriteOnReadOnlyAccessDbException extends KernelException {

    private WriteOnReadOnlyAccessDbException(ErrorGqlStatusObject gqlStatusObject, String message) {
        super(gqlStatusObject, Status.General.WriteOnReadOnlyAccessDatabase, message);
    }

    // KNL-001
    public static WriteOnReadOnlyAccessDbException databaseIsReadOnly() {
        return new WriteOnReadOnlyAccessDbException(
                ErrorGqlStatusObjectImplementation.from(GqlStatusInfoCodes.STATUS_42N18)
                        .build(),
                "This Neo4j server is read-only for all databases");
    }

    // KNL-002
    public static WriteOnReadOnlyAccessDbException databaseIsReadOnly(String databaseName) {
        return new WriteOnReadOnlyAccessDbException(
                ErrorGqlStatusObjectImplementation.from(GqlStatusInfoCodes.STATUS_42N18)
                        .build(),
                "The database " + databaseName + " is in read-only mode on this Neo4j server");
    }
}
