/*
 * Copyright (c) "Neo4j"
 * Neo4j Sweden AB [https://neo4j.com]
 *
 * This file is part of Neo4j.
 *
 * Neo4j is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <https://www.gnu.org/licenses/>.
 */
package org.neo4j.kernel.database;

import static java.util.Objects.requireNonNull;

import java.util.Locale;

public record NormalizedDatabaseName(String name) implements Comparable<NormalizedDatabaseName> {
    public static String normalize(String name) {
        requireNonNull(name, "Database name should be not null.");
        return name.toLowerCase(Locale.ROOT);
    }

    public NormalizedDatabaseName(String name) {
        this.name = normalize(name);
    }

    @Override
    public int compareTo(NormalizedDatabaseName other) {
        return name.compareTo(other.name);
    }
}
