/*
 * Copyright (c) "Neo4j"
 * Neo4j Sweden AB [https://neo4j.com]
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.neo4j.cypher.internal.frontend.phases;

import java.util.concurrent.ConcurrentHashMap;
import java.util.concurrent.atomic.LongAdder;

public final class InternalUsageStatsImpl implements InternalUsageStats {

    private final ConcurrentHashMap<SyntaxUsageMetricKey, LongAdder> syntaxUsageCounts = new ConcurrentHashMap<>();
    private final ConcurrentHashMap<SchemaInferenceUsageMetricKey, LongAdder> labelInferenceUsageCounts =
            new ConcurrentHashMap<>();

    @Override
    public void incrementSyntaxUsageCount(SyntaxUsageMetricKey key) {
        syntaxUsageCounts.computeIfAbsent(key, k -> new LongAdder()).increment();
    }

    @Override
    public long getSyntaxUsageCount(SyntaxUsageMetricKey key) {
        var count = syntaxUsageCounts.get(key);
        return count == null ? 0L : count.longValue();
    }

    @Override
    public void incrementSchemaInferenceUsageCount(SchemaInferenceUsageMetricKey key) {
        labelInferenceUsageCounts.computeIfAbsent(key, k -> new LongAdder()).increment();
    }

    @Override
    public long getSchemaInferenceUsageCount(SchemaInferenceUsageMetricKey key) {
        var count = labelInferenceUsageCounts.get(key);
        return count == null ? 0L : count.longValue();
    }
}
