/*
 * Copyright (c) "Neo4j"
 * Neo4j Sweden AB [https://neo4j.com]
 *
 * This file is part of Neo4j.
 *
 * Neo4j is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <https://www.gnu.org/licenses/>.
 */
package org.neo4j.internal.collector;

interface Anonymizer {
    String propertyKey(String name, int id);

    String label(String name, int id);

    String relationshipType(String name, int id);

    Anonymizer PLAIN_TEXT = new Anonymizer() {
        @Override
        public String propertyKey(String name, int id) {
            return name;
        }

        @Override
        public String label(String name, int id) {
            return name;
        }

        @Override
        public String relationshipType(String name, int id) {
            return name;
        }
    };

    Anonymizer IDS = new Anonymizer() {
        @Override
        public String propertyKey(String name, int id) {
            return "p" + id;
        }

        @Override
        public String label(String name, int id) {
            return "L" + id;
        }

        @Override
        public String relationshipType(String name, int id) {
            return "R" + id;
        }
    };
}
