/*
 * Copyright (c) "Neo4j"
 * Neo4j Sweden AB [https://neo4j.com]
 *
 * This file is part of Neo4j.
 *
 * Neo4j is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <https://www.gnu.org/licenses/>.
 */
package org.neo4j.internal.batchimport.input;

import org.neo4j.internal.batchimport.input.csv.Header;
import org.neo4j.internal.batchimport.input.csv.Header.Entry;

public class DuplicateHeaderException extends HeaderException {
    private final Entry first;
    private final Entry other;

    public DuplicateHeaderException(Header.Entry first, Header.Entry other, String sourceDescription) {
        this(first, other, sourceDescription, null);
    }

    public DuplicateHeaderException(
            Header.Entry first, Header.Entry other, String sourceDescription, String additionalInformation) {
        super("Duplicate header entries found in " + sourceDescription + ", first " + first
                + ", other (and conflicting) " + other
                + (additionalInformation != null ? " " + additionalInformation : ""));
        this.first = first;
        this.other = other;
    }

    public Entry getFirst() {
        return first;
    }

    public Entry getOther() {
        return other;
    }
}
