/*
 * Copyright (c) "Neo4j"
 * Neo4j Sweden AB [https://neo4j.com]
 *
 * This file is part of Neo4j.
 *
 * Neo4j is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <https://www.gnu.org/licenses/>.
 */
package org.neo4j.io.fs.watcher.resource;

import java.io.Closeable;
import java.nio.file.Path;
import java.nio.file.WatchKey;
import org.neo4j.io.fs.watcher.FileWatcher;

/**
 * Resource watched by {@link FileWatcher}.
 *
 * Should be closed if further monitoring is not required.
 */
public interface WatchedResource extends Closeable {

    WatchedResource EMPTY = new WatchedResource() {
        @Override
        public Path getWatchedFile() {
            return null;
        }

        @Override
        public WatchKey getWatchKey() {
            return null;
        }

        @Override
        public void close() {}
    };

    Path getWatchedFile();

    WatchKey getWatchKey();
}
