/*
 * Copyright (c) "Neo4j"
 * Neo4j Sweden AB [https://neo4j.com]
 *
 * This file is part of Neo4j.
 *
 * Neo4j is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <https://www.gnu.org/licenses/>.
 */
package org.neo4j.internal.kernel.api.exceptions;

import org.neo4j.exceptions.KernelException;
import org.neo4j.gqlstatus.ErrorGqlStatusObject;
import org.neo4j.gqlstatus.ErrorGqlStatusObjectImplementation;
import org.neo4j.gqlstatus.GqlStatusInfoCodes;
import org.neo4j.kernel.api.exceptions.Status;

/**
 * This exception is thrown when committing a transaction contains
 * violations to any constraints defined for the database.
 */
public class ConstraintViolationTransactionFailureException extends TransactionFailureException {

    private ConstraintViolationTransactionFailureException(String msg, KernelException cause) {
        super(Status.Schema.ConstraintValidationFailed, cause, msg);
    }

    protected ConstraintViolationTransactionFailureException(ErrorGqlStatusObject gqlStatusObject, String msg) {
        super(gqlStatusObject, Status.Schema.ConstraintValidationFailed, msg);
    }

    private ConstraintViolationTransactionFailureException(
            ErrorGqlStatusObject gqlStatusObject, KernelException cause, String msg) {
        super(gqlStatusObject, Status.Schema.ConstraintValidationFailed, cause, msg);
    }

    public static ConstraintViolationTransactionFailureException create(String msg, KernelException cause) {
        if (cause.gqlStatusObject() != null) {
            // Except for the protected constructor and the genericViolationFailure method, the cause
            // will always provide the correct GQL status object.
            return new ConstraintViolationTransactionFailureException(cause.gqlStatusObject(), cause, msg);
        }
        // But some causes don't have the GQL status object implemented _yet_.
        return new ConstraintViolationTransactionFailureException(msg, cause);
    }

    // KNL-065
    public static ConstraintViolationTransactionFailureException genericViolationFailure(String msg) {
        var gql = ErrorGqlStatusObjectImplementation.from(GqlStatusInfoCodes.STATUS_50N14)
                .build();
        return new ConstraintViolationTransactionFailureException(gql, msg);
    }
}
