/*
 * Copyright (c) "Neo4j"
 * Neo4j Sweden AB [https://neo4j.com]
 *
 * This file is part of Neo4j.
 *
 * Neo4j is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <https://www.gnu.org/licenses/>.
 */
package org.neo4j.kernel.database;

import static org.assertj.core.api.Assertions.assertThat;

import org.junit.jupiter.api.Test;
import org.neo4j.kernel.lifecycle.LifeSupport;
import org.neo4j.logging.internal.DatabaseLogProvider;
import org.neo4j.monitoring.Monitors;

public class DefaultDatabaseMonitorsFactoryTest {

    @Test
    void shouldAddToLife() {

        var databaseMonitors = new DatabaseMonitors(new Monitors(), DatabaseLogProvider.nullDatabaseLogProvider());
        var listener = new Object();

        databaseMonitors.addMonitorListener(listener);
        assertThat(databaseMonitors.getRegisteredMonitors()).contains(listener);

        var lifeSupport = new LifeSupport();
        assertThat(new DefaultDatabaseMonitorsFactory(databaseMonitors).create(lifeSupport))
                .isSameAs(databaseMonitors);

        lifeSupport.start();
        lifeSupport.shutdown();
        assertThat(databaseMonitors.getRegisteredMonitors()).isEmpty();
    }
}
