/*
 * Copyright (c) "Neo4j"
 * Neo4j Sweden AB [https://neo4j.com]
 *
 * This file is part of Neo4j.
 *
 * Neo4j is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <https://www.gnu.org/licenses/>.
 */
package org.neo4j.kernel.api.exceptions;

import org.neo4j.exceptions.KernelException;
import org.neo4j.gqlstatus.ErrorGqlStatusObject;
import org.neo4j.gqlstatus.ErrorGqlStatusObjectImplementation;
import org.neo4j.gqlstatus.GqlParams;
import org.neo4j.gqlstatus.GqlStatusInfoCodes;

public class RelationshipTypeNotFoundException extends KernelException {

    private RelationshipTypeNotFoundException(
            ErrorGqlStatusObject gqlStatusObject, String relationshipType, Exception cause) {
        super(
                gqlStatusObject,
                Status.Schema.RelationshipTypeAccessFailed,
                cause,
                "Relationship type '" + relationshipType + "' not found");
    }

    public static RelationshipTypeNotFoundException relationshipTypeNotFound(String relationshipType, Exception cause) {
        var gql = ErrorGqlStatusObjectImplementation.from(GqlStatusInfoCodes.STATUS_22N62)
                .withParam(GqlParams.StringParam.relType, relationshipType)
                .build();
        return new RelationshipTypeNotFoundException(gql, relationshipType, cause);
    }
}
