/*
 * Copyright (c) "Neo4j"
 * Neo4j Sweden AB [https://neo4j.com]
 *
 * This file is part of Neo4j.
 *
 * Neo4j is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <https://www.gnu.org/licenses/>.
 */
package org.neo4j.procedure;

import java.lang.annotation.ElementType;
import java.lang.annotation.Retention;
import java.lang.annotation.RetentionPolicy;
import java.lang.annotation.Target;
import org.neo4j.annotations.api.PublicApi;

/**
 * This marks a field in a class with {@link Procedure} methods as part of the context the procedure is invoked in.
 * Practically, this means that before the procedure is called, fields with this annotation are automatically
 * populated with implementations of the specified APIs.
 *
 * In fact, apart from static fields, <i>only</i> fields with this annotation are allowed in classes that
 * define procedures. Each of the fields must be public and non-final.
 *
 * @see Procedure
 */
@Target(ElementType.FIELD)
@Retention(RetentionPolicy.RUNTIME)
@PublicApi
public @interface Context {}
