/*
 * Copyright (c) "Neo4j"
 * Neo4j Sweden AB [https://neo4j.com]
 *
 * This file is part of Neo4j.
 *
 * Neo4j is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <https://www.gnu.org/licenses/>.
 */
package org.neo4j.kernel.impl.store;

import org.neo4j.io.pagecache.PageCursor;

public class IntStoreHeaderFormat implements StoreHeaderFormat<IntStoreHeader> {
    protected final int header;

    public IntStoreHeaderFormat(int header) {
        this.header = header;
    }

    @Override
    public int numberOfReservedRecords() {
        return 1;
    }

    @Override
    public void writeHeader(PageCursor cursor) {
        cursor.putInt(header);
    }

    @Override
    public IntStoreHeader readHeader(PageCursor cursor) {
        return new IntStoreHeader(cursor.getInt());
    }

    @Override
    public IntStoreHeader generateHeader() {
        return new IntStoreHeader(header);
    }
}
