/*
 * Copyright (c) "Neo4j"
 * Neo4j Sweden AB [https://neo4j.com]
 *
 * This file is part of Neo4j.
 *
 * Neo4j is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <https://www.gnu.org/licenses/>.
 */
package org.neo4j.server.http.cypher.format.api;

import java.util.List;
import java.util.function.Function;

public class RecordEvent implements OutputEvent {

    private final List<String> columns;
    private final Function<String, Object> valueSupplier;

    public RecordEvent(List<String> columns, Function<String, Object> valueSupplier) {
        this.columns = columns;
        this.valueSupplier = valueSupplier;
    }

    @Override
    public Type getType() {
        return Type.RECORD;
    }

    public List<String> getColumns() {
        return columns;
    }

    public Object getValue(String column) {
        return valueSupplier.apply(column);
    }
}
